JmapClientStdError

Enum JmapClientStdError 

pub enum JmapClientStdError {
Show 41 variants Send(JmapSendError), SessionGet(JmapSessionGetError), BlobUpload(JmapBlobUploadError), BlobDownload(JmapBlobDownloadError), PushSubscriptionGet(JmapPushSubscriptionGetError), PushSubscriptionSet(JmapPushSubscriptionSetError), MailboxGet(JmapMailboxGetError), MailboxQuery(JmapMailboxQueryError), MailboxSet(JmapMailboxSetError), MailboxChanges(JmapMailboxChangesError), EmailGet(JmapEmailGetError), EmailQuery(JmapEmailQueryError), EmailSet(JmapEmailSetError), EmailChanges(JmapEmailChangesError), EmailCopy(JmapEmailCopyError), EmailImport(JmapEmailImportError), EmailParse(JmapEmailParseError), ThreadGet(JmapThreadGetError), ThreadChanges(JmapThreadChangesError), IdentityGet(JmapIdentityGetError), IdentitySet(JmapIdentitySetError), EmailSubmissionGet(JmapEmailSubmissionGetError), EmailSubmissionQuery(JmapEmailSubmissionQueryError), EmailSubmissionSet(JmapEmailSubmissionSetError), EmailSubmissionCancel(JmapEmailSubmissionCancelError), VacationResponseGet(JmapVacationResponseGetError), VacationResponseSet(JmapVacationResponseSetError), AddressBookGet(JmapAddressBookGetError), AddressBookSet(JmapAddressBookSetError), AddressBookChanges(JmapAddressBookChangesError), ContactCardGet(JmapContactCardGetError), ContactCardQuery(JmapContactCardQueryError), ContactCardSet(JmapContactCardSetError), ContactCardChanges(JmapContactCardChangesError), ContactCardCopy(JmapContactCardCopyError), Io(Error), Tls(Error), UrlMissingHost(String), UrlUnsupportedScheme { url: String, scheme: String, }, UnexpectedRedirect(Url), MissingSession,
}
Available on crate feature client only.
Errors returned by JmapClientStd.

Variants



Send(JmapSendError)

The raw send coroutine failed.



SessionGet(JmapSessionGetError)

The session fetch coroutine failed.



BlobUpload(JmapBlobUploadError)

The blob upload coroutine failed.



BlobDownload(JmapBlobDownloadError)

The blob download coroutine failed.



PushSubscriptionGet(JmapPushSubscriptionGetError)

The PushSubscription/get coroutine failed.



PushSubscriptionSet(JmapPushSubscriptionSetError)

The PushSubscription/set coroutine failed.



MailboxGet(JmapMailboxGetError)

The Mailbox/get coroutine failed.



MailboxQuery(JmapMailboxQueryError)

The Mailbox/query coroutine failed.



MailboxSet(JmapMailboxSetError)

The Mailbox/set coroutine failed.



MailboxChanges(JmapMailboxChangesError)

The Mailbox/changes coroutine failed.



EmailGet(JmapEmailGetError)

The Email/get coroutine failed.



EmailQuery(JmapEmailQueryError)

The Email/query coroutine failed.



EmailSet(JmapEmailSetError)

The Email/set coroutine failed.



EmailChanges(JmapEmailChangesError)

The Email/changes coroutine failed.



EmailCopy(JmapEmailCopyError)

The Email/copy coroutine failed.



EmailImport(JmapEmailImportError)

The Email/import coroutine failed.



EmailParse(JmapEmailParseError)

The Email/parse coroutine failed.



ThreadGet(JmapThreadGetError)

The Thread/get coroutine failed.



ThreadChanges(JmapThreadChangesError)

The Thread/changes coroutine failed.



IdentityGet(JmapIdentityGetError)

The Identity/get coroutine failed.



IdentitySet(JmapIdentitySetError)

The Identity/set coroutine failed.



EmailSubmissionGet(JmapEmailSubmissionGetError)

The EmailSubmission/get coroutine failed.



EmailSubmissionQuery(JmapEmailSubmissionQueryError)

The EmailSubmission/query coroutine failed.



EmailSubmissionSet(JmapEmailSubmissionSetError)

The EmailSubmission/set coroutine failed.



EmailSubmissionCancel(JmapEmailSubmissionCancelError)

The EmailSubmission/set cancel coroutine failed.



VacationResponseGet(JmapVacationResponseGetError)

The VacationResponse/get coroutine failed.



VacationResponseSet(JmapVacationResponseSetError)

The VacationResponse/set coroutine failed.



AddressBookGet(JmapAddressBookGetError)

The AddressBook/get coroutine failed.



AddressBookSet(JmapAddressBookSetError)

The AddressBook/set coroutine failed.



AddressBookChanges(JmapAddressBookChangesError)

The AddressBook/changes coroutine failed.



ContactCardGet(JmapContactCardGetError)

The ContactCard/get coroutine failed.



ContactCardQuery(JmapContactCardQueryError)

The ContactCard/query coroutine failed.



ContactCardSet(JmapContactCardSetError)

The ContactCard/set coroutine failed.



ContactCardChanges(JmapContactCardChangesError)

The ContactCard/changes coroutine failed.



ContactCardCopy(JmapContactCardCopyError)

The ContactCard/copy coroutine failed.



Io(Error)

The underlying stream failed to read or write.



Tls(Error)

Available on crate features native-tls or rustls-aws or rustls-ring only.

The TCP connection or the TLS negotiation failed.



UrlMissingHost(String)

Available on crate features native-tls or rustls-aws or rustls-ring only.

The URL to connect to carries no host.



UrlUnsupportedScheme

Available on crate features native-tls or rustls-aws or rustls-ring only.

The URL to connect to carries a scheme the client cannot open.

Fields

url: String

The URL the client was asked to open.

scheme: String

The unsupported scheme of that URL.



UnexpectedRedirect(Url)

The server answered with a redirect during a non-redirectable operation.



MissingSession

A method requiring the session ran before JmapClientStd::session_get.