pub struct JmapQueryOptions<F: Serialize, S: Serialize> {
pub filter: Option<F>,
pub sort: Option<Vec<S>>,
pub position: Option<u64>,
pub anchor: Option<String>,
pub anchor_offset: Option<i64>,
pub limit: Option<u64>,
pub calculate_total: bool,
}Expand description
Options for JmapQuery::new.
Fields
filter: Option<F>The filter conditions the objects must match.
sort: Option<Vec<S>>The sort comparators applied to the results.
position: Option<u64>Zero-based index of the first result to return.
anchor: Option<String>Id of the object to anchor the result window on.
anchor_offset: Option<i64>Offset of the result window relative to the anchor.
limit: Option<u64>Maximum number of results to return.
calculate_total: boolAsk the server to compute total. Off by default.