pub struct JmapEmailParseOutput {
pub parsed: BTreeMap<String, JmapEmail>,
pub not_parsable: Vec<String>,
pub not_found: Vec<String>,
pub keep_alive: bool,
}Expand description
Successful terminal output of JmapEmailParse.
Fields
parsed: BTreeMap<String, JmapEmail>The parsed emails, keyed by blob id.
not_parsable: Vec<String>Blob ids that could not be parsed as messages.
not_found: Vec<String>The requested ids the server did not find.
keep_alive: boolWhether the server indicated the connection can be reused.