pub enum JmapEmailSortProperty {
ReceivedAt,
SentAt,
Size,
From,
To,
Subject,
HasAttachment,
Keyword,
AllInThreadHaveKeyword,
SomeInThreadHaveKeyword,
}Expand description
Sort property for Email/query (RFC 8621 4.4).
Variants
ReceivedAt
Sort by receive time.
SentAt
Sort by the Date header.
Size
Sort by message size.
From
Sort by the first From address.
To
Sort by the first To address.
Subject
Sort by the base subject.
HasAttachment
Sort by attachment presence.
Keyword
Sort by keyword presence on the email (requires keyword field).
AllInThreadHaveKeyword
Sort by whether all emails in the thread have a keyword
(requires keyword field).
SomeInThreadHaveKeyword
Sort by whether some emails in the thread have a keyword
(requires keyword field).