JmapEmailSetArgs

Struct JmapEmailSetArgs 

pub struct JmapEmailSetArgs {
    pub create: Option<BTreeMap<String, JmapEmail>>,
    pub update: Option<BTreeMap<String, JmapEmailPatch>>,
    pub destroy: Option<Vec<String>>,
}
Arguments for an Email/set request.

Fields

create: Option<BTreeMap<String, JmapEmail>>

Objects to create (client ID → partial email object).

update: Option<BTreeMap<String, JmapEmailPatch>>

Objects to update (email ID → patch).

destroy: Option<Vec<String>>

IDs to destroy (delete).

Implementations

Source

impl JmapEmailSetArgs

pub fn create( &mut self, client_id: impl Into<String>, email: JmapEmail, ) -> &mut Self

Queue an email for creation under the given client-chosen ID.

pub fn destroy(&mut self, id: impl Into<String>) -> &mut Self

Queue an email ID for destruction.

pub fn set_keyword( &mut self, id: impl Into<String>, keyword: impl Into<String>, ) -> &mut Self

Queues a patch setting a keyword on the email with the given id.

pub fn unset_keyword( &mut self, id: impl Into<String>, keyword: impl Into<String>, ) -> &mut Self

Queues a patch unsetting a keyword on the email with the given id.

pub fn replace_keywords( &mut self, id: impl Into<String>, keywords: BTreeMap<String, bool>, ) -> &mut Self

Queues a patch replacing all keywords of the email with the given id.

pub fn add_to_mailbox( &mut self, id: impl Into<String>, mailbox_id: impl Into<String>, ) -> &mut Self

Queues a patch adding the email with the given id to a mailbox.

pub fn remove_from_mailbox( &mut self, id: impl Into<String>, mailbox_id: impl Into<String>, ) -> &mut Self

Queues a patch removing the email with the given id from a mailbox.

pub fn replace_mailbox_ids( &mut self, id: impl Into<String>, ids: BTreeMap<String, bool>, ) -> &mut Self

Queues a patch replacing the mailbox membership of the email with the given id.