pub struct JmapEmailSubmissionQueryOutput {
pub submissions: Vec<JmapEmailSubmission>,
pub total: Option<u64>,
pub position: u64,
pub query_state: String,
pub keep_alive: bool,
}Expand description
Successful terminal output of JmapEmailSubmissionQuery.
Fields
submissions: Vec<JmapEmailSubmission>The fetched email submissions.
total: Option<u64>The total number of matching objects, when the server computed it.
position: u64Zero-based index of the first returned id.
query_state: StringThe state the query results were computed at.
keep_alive: boolWhether the server indicated the connection can be reused.