pub struct JmapIdentitySetArgs {
pub create: BTreeMap<String, JmapIdentityCreate>,
pub update: BTreeMap<String, JmapIdentityUpdate>,
pub destroy: Vec<String>,
}Expand description
Arguments for an Identity/set request.
Fields
create: BTreeMap<String, JmapIdentityCreate>The identities to create, keyed by client id.
update: BTreeMap<String, JmapIdentityUpdate>The patches to apply, keyed by identity id.
destroy: Vec<String>The ids of the objects to destroy.
Implementations
Sourceimpl JmapIdentitySetArgs
impl JmapIdentitySetArgs
Sourcepub fn create(
&mut self,
client_id: impl Into<String>,
identity: JmapIdentityCreate,
) -> &mut Self
pub fn create( &mut self, client_id: impl Into<String>, identity: JmapIdentityCreate, ) -> &mut Self
Queues an object to create under the given client id.
Sourcepub fn update(
&mut self,
id: impl Into<String>,
patch: JmapIdentityUpdate,
) -> &mut Self
pub fn update( &mut self, id: impl Into<String>, patch: JmapIdentityUpdate, ) -> &mut Self
Queues a patch for the identity with the given id.