JmapEmailFilter

Struct JmapEmailFilter 

pub struct JmapEmailFilter {
Show 19 fields pub in_mailbox: Option<String>, pub in_mailbox_other_than: Option<Vec<String>>, pub before: Option<String>, pub after: Option<String>, pub min_size: Option<u64>, pub max_size: Option<u64>, pub all_in_thread_have_keyword: Option<String>, pub some_in_thread_have_keyword: Option<String>, pub none_in_thread_have_keyword: Option<String>, pub has_keyword: Option<String>, pub not_keyword: Option<String>, pub has_attachment: Option<bool>, pub text: Option<String>, pub from: Option<String>, pub to: Option<String>, pub cc: Option<String>, pub bcc: Option<String>, pub subject: Option<String>, pub body: Option<String>,
}
Filter condition for Email/query (RFC 8621 4.4).

Fields

in_mailbox: Option<String>

Only messages in this mailbox ID.

in_mailbox_other_than: Option<Vec<String>>

Exclude messages in any of these mailbox IDs.

before: Option<String>

RFC 3339 upper bound.

after: Option<String>

RFC 3339 lower bound.

min_size: Option<u64>

Only messages of at least this size, in bytes.

max_size: Option<u64>

Only messages strictly below this size, in bytes.

all_in_thread_have_keyword: Option<String>

Only threads where every email carries this keyword.

some_in_thread_have_keyword: Option<String>

Only threads where at least one email carries this keyword.

none_in_thread_have_keyword: Option<String>

Only threads where no email carries this keyword.

has_keyword: Option<String>

Only messages carrying this keyword.

not_keyword: Option<String>

Only messages not carrying this keyword.

has_attachment: Option<bool>

Only messages with (or without) attachments.

text: Option<String>

Full-text search query.

from: Option<String>

Text search over the From header.

to: Option<String>

Text search over the To header.

cc: Option<String>

Text search over the Cc header.

bcc: Option<String>

Text search over the Bcc header.

subject: Option<String>

Text search over the Subject header.

body: Option<String>

Text search over the message body.